import { ElementRef, EventEmitter } from '@angular/core';
import { DialogService } from '../../shared/services/dialog.service';
import { Observable } from 'rxjs';
import { AnimationEvent } from '@angular/animations';
import * as i0 from "@angular/core";
/**
 * Component to display a dialog with dynamic content
 */
export declare class DialogComponent {
    private dialogService;
    /**
     * Element reference to the dialog close button
     */
    closeButton: ElementRef<HTMLButtonElement>;
    /**
     * Observable to update the effective width of the dialog on screen resize
     */
    effectiveWidth$: Observable<string>;
    /**
     * Object to operate whether the dialog is open/closed
     */
    private _object;
    /**
     * Object to operate whether the dialog is open/closed
     */
    set object(value: any);
    get object(): any;
    /**
     * Title to show at the top of the dialog
     */
    title: string;
    /**
     * Class to apply to the title of the dialog
     */
    titleClass: string;
    /**
     * Show or hide the title bar
     */
    showTitle: boolean;
    /**
     * Whether to show close button and allow escape to close
     */
    allowClose: boolean;
    /**
     * Class to apply to the body of the dialog
     */
    bodyClass: string;
    /**
     * Height of the dialog (can use any height measurement)
     */
    height: string;
    /**
     * Width of the dialog (can use any width measurement)
     */
    width: string;
    /**
     * Event Emitter for when the dialog is closed
     */
    closed: EventEmitter<any>;
    /**
     * Event emitted when dialog has finished opening
     */
    opened: EventEmitter<void>;
    /**
     * Dependency injection site
     * @param dialogService the dialog service
     */
    constructor(dialogService: DialogService);
    /**
     * Null the object to close the dialog, emit the close event.
     */
    close(): void;
    /**
     * Method for compatibility with legacy dialog API. Method does nothing.
     */
    open(): void;
    /**
     * Emit closed/opened events based on state when dialog animation ends
     * @param event
     */
    onAnimationDone(event: AnimationEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DialogComponent, "wily-dialog", never, { "object": "object"; "title": "title"; "titleClass": "titleClass"; "showTitle": "showTitle"; "allowClose": "allowClose"; "bodyClass": "bodyClass"; "height": "height"; "width": "width"; }, { "closed": "closed"; "opened": "opened"; }, never, ["*"]>;
}
