import * as i0 from "@angular/core";
/**
 * Type representing the available Wily icon filter options
 */
declare type WilyIconFilterOption = 'all' | 'solid' | 'regular' | 'light';
/**
 * Type representing the available Fontawesome icon filter options
 */
declare type FontawesomeIconFilterOption = 'all' | 'solid' | 'regular' | 'brands';
/**
 * Service for filtering Wily/Fontawesome icons
 */
export declare class IconsService {
    /**
     * Get Fontawesome icons filtered by icon type
     * @param filter the icon type to filter by
     * @private
     */
    private static getFontawesomeIcons;
    /**
     * Get Wily icons filtered by icon type
     * @param filter the icon type to filter by
     * @private
     */
    private static getWilyIcons;
    /**
     * Constructor
     */
    constructor();
    /**
     * Get a list of icons (as strings) containing both Wily icons
     * and Fontawesome icons that match their respective filter criteria
     * @param iconType the type of icon, or all icons
     * @param filter the icon styling to filter by
     * @param searchText the search text to filter icons by
     */
    getIcons(iconType: 'all' | 'wily' | 'fontawesome', filter: WilyIconFilterOption | FontawesomeIconFilterOption, searchText?: string): Array<{
        prefix: string;
        name: string;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<IconsService>;
}
export {};
