import { ElementRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Directive to apply key filtering to an HTML input element
 */
export declare class KeyfilterDirective {
    private hostElement;
    /**
     * Array of keyboard key names that are always allowed
     * (arrow keys, backspace, delete, tab, escape)
     * @private
     */
    private static readonly ALLOWED_KEYS;
    /**
     * Array of keyboard alpha key names
     * @private
     */
    private static readonly ALPHA_KEYS;
    /**
     * The type of filtering to apply
     */
    filterType: 'alpha' | 'numeric' | 'alphanumeric';
    /**
     * Whether or not to allow spaces (default false)
     */
    allowSpaces: boolean;
    /**
     * Determine if the input key is numeric (a digit)
     * @param key the key to test
     * @private
     */
    private static keyIsNumeric;
    /**
     * Determine if the input key is an alpha key (a letter of
     * the English alphabet)
     * @param key the key to test
     * @private
     */
    private static keyIsAlpha;
    /**
     * Dependency injection site
     * @param hostElement
     */
    constructor(hostElement: ElementRef<HTMLInputElement>);
    /**
     * Filter out keys based on the specified filter type
     * @param event the keydown KeyboardEvent
     */
    onKeyDown(event: KeyboardEvent): void;
    /**
     * Prevent paste if input contains forbidden characters
     * @param event the paste ClipboardEvent
     */
    onPaste(event: ClipboardEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<KeyfilterDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<KeyfilterDirective, "[wilyKeyfilter]", never, { "filterType": "wilyKeyfilter"; "allowSpaces": "allowSpaces"; }, {}, never>;
}
