import { Observable } from 'rxjs';
import { Notification } from '../models/notification.model';
import * as i0 from "@angular/core";
/**
 * Service for adding/deleting notifications
 */
export declare class NotificationService {
    /**
     * Valid characters that a notification ID can be composed from
     * @private
     */
    private static readonly ID_CHARACTERS;
    /**
     * BehaviorSubject tracking an array of active notifications
     * @private
     */
    private readonly _notifications;
    /**
     * The number of milliseconds before an added notification automatically removes itself.
     * Defaults to 3000 milliseconds
     * @private
     */
    private notificationLife;
    /**
     * Generate a random ID
     * @private
     */
    private static generateId;
    /**
     * Dependency injection site
     */
    constructor();
    /**
     * Add a notification
     * @param notification the notification to add
     */
    add(notification: Notification): void;
    /**
     * Delete a notification
     * @param id the ID of the notification to delete
     */
    deleteNotification(id: string): void;
    /**
     * Get notifications as an Observable
     */
    getNotifications(): Observable<Array<Notification>>;
    /**
     * Set the number of milliseconds before added notifications disappear
     * @param milliseconds the number of milliseconds to set
     */
    setNotificationLife(milliseconds: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NotificationService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NotificationService>;
}
