import { EventEmitter, OnChanges } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A Wily paginator, because we hated the other ones on the market.
 */
export declare class PaginatorComponent implements OnChanges {
    /**
     * Paginator Version to use (1-4 available, 1 is default)
     */
    version: string;
    /**
     * An array of potential page sizes.
     */
    pageSizeOptions: Array<number>;
    /**
     * Current page size
     */
    pageSize: number;
    /**
     * Total number of items
     */
    totalLength: number;
    /**
     * Event Emitter for pagination or page size change.
     */
    paginate: EventEmitter<any>;
    /**
     * Currently active page
     */
    activePage: number;
    /**
     * For the page jump text input
     */
    pageJumpInput: string;
    /**
     * Number of pages
     */
    numberOfPages: number;
    /**
     * Recalculate number of pages on input change
     */
    ngOnChanges(): void;
    /**
     * Goes to the first page
     */
    goToFirst(): void;
    /**
     * Goes to the last page
     */
    goToLast(): void;
    /**
     * Calculates the number of pages
     */
    getNumberOfPages(): number;
    /**
     * Goes to a given page and emits a pagination event
     *
     * @param pageNumber
     * @param inputFocus
     */
    goToPage(pageNumber: number, inputFocus?: boolean): void;
    /**
     * Emits a pagination event with the current paginator data
     */
    emitEvent(): void;
    /**
     * Determines whether a given page exists or not.
     *
     * @param pageNumber
     */
    hasPage(pageNumber: number): boolean;
    /**
     * Gets the first value for a given page
     *
     * @param pageNumber
     */
    getStartingValueForPage(pageNumber: number): number;
    /**
     * Gets the last value for a given page
     *
     * @param pageNumber
     */
    getEndingValueForPage(pageNumber: number): number;
    /**
     * When a page size is changed, go back to the first page and emit a pagination event
     */
    pageSizeChange(): void;
    /**
     * Jump to a page based on user input
     */
    jumpPage(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PaginatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PaginatorComponent, "wily-paginator", never, { "version": "version"; "pageSizeOptions": "pageSizeOptions"; "pageSize": "pageSize"; "totalLength": "totalLength"; }, { "paginate": "paginate"; }, never, never>;
}
