import { AnimationEvent } from '@angular/animations';
import { EventEmitter, OnDestroy, Renderer2 } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * TODO: allow attachment of popover to another specified element
 * TODO: allow configuration of attachment corner (top left, bottom left, etc)
 */
/**
 * Component to display a popover with custom content
 */
export declare class PopoverComponent implements OnDestroy {
    private renderer;
    /**
     * The keyboard arrow keys
     * @private
     */
    private static ARROW_KEYS;
    /**
     * The offset of the popover from its target (in pixels)
     */
    offset: number;
    /**
     * Set the width of the popover in pixels (defaults to auto)
     */
    set width(width: number);
    /**
     * Set the height of the popover in pixels (defaults to auto)
     */
    set height(height: number);
    /**
     * A class-list to apply to the popover content
     */
    classList: string;
    /**
     * Event emitted on popover open
     */
    opened: EventEmitter<void>;
    /**
     * Event emitted on popover close
     */
    closed: EventEmitter<void>;
    /**
     * Whether or not the popover should render
     */
    render: boolean;
    /**
     * Whether or not the popover is visible
     */
    visible: boolean;
    /**
     * The width of the popover
     */
    _width: string;
    /**
     * The height of the popover
     */
    _height: string;
    /**
     * The element to target
     * @private
     */
    private target;
    /**
     * The popover content container
     * @private
     */
    private container;
    /**
     * Array of escape keyup unlisten functions
     * @private
     */
    private escapeKeyUpUnlisteners;
    /**
     * Dependency injection site
     * @param renderer the Angular renderer
     */
    constructor(renderer: Renderer2);
    /**
     * Destroy component, clean up event listeners
     */
    ngOnDestroy(): void;
    /**
     * Close popover on click
     * @param event the click MouseEvent
     */
    onClick(event: MouseEvent): void;
    /**
     * Prevent arrow key scrolling while popover is open
     */
    onKeyDown(event: KeyboardEvent): void;
    /**
     * Re-position popover on window resize
     */
    onWindowResize(): void;
    /**
     * Toggle the popover from open to closed or closed to open
     * @param event the event whose target element will act as
     *              the popover target. If an event is not provided,
     *              the popover will close
     */
    toggle(event?: Event): void;
    /**
     * Handle animation start
     * @param event the AnimationEvent
     */
    onAnimationStart(event: AnimationEvent): void;
    /**
     * Handle animation end
     * @param event the AnimationEvent
     */
    onAnimationDone(event: AnimationEvent): void;
    /**
     * Open the popover
     * @private
     */
    private open;
    /**
     * Close the popover
     * @private
     */
    private close;
    /**
     * Position the popover
     * @private
     */
    private positionPopover;
    /**
     * Add escape keyup listeners to all focusable elements to close
     * the popover
     * @private
     */
    private addEventListeners;
    /**
     * Get all focusable child elements of the input node
     * @param node the node to query for focusable children
     * @param elements the found focusable elements
     * @private
     */
    private getFocusableElements;
    /**
     * Invoke escape keyup unlisten functions
     * @private
     */
    private removeEventListeners;
    static ɵfac: i0.ɵɵFactoryDeclaration<PopoverComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PopoverComponent, "wily-popover", never, { "offset": "offset"; "width": "width"; "height": "height"; "classList": "classList"; }, { "opened": "opened"; "closed": "closed"; }, never, ["*"]>;
}
