import { AfterViewInit, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Push Container that'll either push the content or overlay the content based on screen width.
 */
export declare class PushContainerComponent implements OnInit, AfterViewInit, OnDestroy {
    /**
     * Width of the container in pixels.
     */
    width: number;
    /**
     * Show the side panel on load?
     */
    showSidePanel: boolean;
    /**
     * Main Content ID that will be pushed by this
     */
    mainContentId: string;
    /**
     * Side to push from (left/right)
     */
    side: string;
    /**
     * Top offset to account for a nav bar
     */
    topOffset: string;
    /**
     * If the screen resizes, it will either overlay or close depending on this variable
     */
    closeOnResize: boolean;
    /**
     * Background color for the container
     */
    backgroundColorClass: string;
    /**
     * Breakpoint that will make the container take over the screen when it's crossed.
     */
    breakpoint: number;
    /**
     * Whether or not to always hide the close button, defaults to false.
     */
    hideCloseButton: boolean;
    /**
     * Whether or not to show the close button on desktop. Defaults to false.
     */
    alwaysShowClose: boolean;
    /**
     * Event emitter for open
     */
    opened: EventEmitter<any>;
    /**
     * Event emitter for close
     */
    closed: EventEmitter<any>;
    /**
     * Visibility variable for accessibility
     */
    visibility: boolean;
    private unclickable;
    /**
     * Private variable to detect if the breakpoint is exceeded
     */
    breakpointExceeded: boolean;
    /**
     * Constructor
     */
    ngOnInit(): void;
    /**
     * Show or close the push container on load depending on the state passed in.
     */
    ngAfterViewInit(): void;
    /**
     * Close the push container on destroy
     */
    ngOnDestroy(): void;
    /**
     * Monitor the screen size and perform actions as specified by the input options
     *
     * @param event
     */
    onResize(event: any): void;
    /**
     * Open or close based on current state.
     */
    toggle(): void;
    /**
     * Open the push container
     *
     * @param init
     */
    open(init?: boolean): void;
    /**
     * Close the push container
     */
    close(): void;
    /**
     * Set the margin
     *
     * @param size
     */
    private setMargin;
    /**
     * Get the width of the container
     */
    getWidth(): string;
    /**
     * Get the side panel class based on the current state.
     */
    getSidePanelClass(): string;
    /**
     * Get the left size based on the options
     */
    getLeftProperty(): string;
    /**
     * Get the right size based on the options
     */
    getRightProperty(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<PushContainerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PushContainerComponent, "wily-push-container", never, { "width": "width"; "showSidePanel": "showSidePanel"; "mainContentId": "mainContentId"; "side": "side"; "topOffset": "topOffset"; "closeOnResize": "closeOnResize"; "backgroundColorClass": "backgroundColorClass"; "breakpoint": "breakpoint"; "hideCloseButton": "hideCloseButton"; "alwaysShowClose": "alwaysShowClose"; }, { "opened": "opened"; "closed": "closed"; }, never, ["*"]>;
}
