import { ChangeDetectorRef, ElementRef, EventEmitter, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * Component that wraps the native HTML5 slider
 */
export declare class SliderComponent implements ControlValueAccessor, OnInit {
    private changeDetectorRef;
    /**
     * ViewChild of the slider input
     */
    sliderInput: ElementRef<HTMLInputElement>;
    /**
     * Set the value of the component
     * @param value the value to set
     */
    set value(value: number);
    /**
     * Set the minimum slider value
     * @param min the value to set
     */
    set min(min: number);
    /**
     * Set the maximum slider value
     * @param max the value to set
     */
    set max(max: number);
    /**
     * Set the slider step size
     * @param step the value to set
     */
    set step(step: number);
    /**
     * Set the disabled state of the slider/input
     * @param disabled the value to set
     */
    set disabled(disabled: boolean);
    /**
     * Set the input class list
     * @param inputClassList the value to set
     */
    set inputClassList(inputClassList: string);
    /**
     * The unit being represented by the slider
     */
    unit: string;
    /**
     * The aria-label to append to the slider/input
     */
    ariaLabel: string;
    /**
     * Event emitted on slider/slider input input event
     */
    input: EventEmitter<number>;
    /**
     * The internal value of the component
     */
    _value: number;
    /**
     * The minimum slider value
     */
    _min: number;
    /**
     * The maximum slider value
     */
    _max: number;
    /**
     * The step size of the slider
     */
    _step: number;
    /**
     * Whether the slider is disabled or not
     */
    _disabled: boolean;
    /**
     * The class list to apply to the number input
     */
    _inputClassList: string;
    /**
     * The width of the colored section of the slider bar
     */
    sliderWidth: number;
    /**
     * Function to call on change
     */
    onChange: (value: any) => void;
    /**
     * Function to call on touch
     */
    onTouched: () => any;
    /**
     * Dependency injection site
     * @param changeDetectorRef the Angular ChangeDetectorRef
     */
    constructor(changeDetectorRef: ChangeDetectorRef);
    /**
     * Get the value of the component
     */
    get value(): number;
    /**
     * Init component
     */
    ngOnInit(): void;
    /**
     * Set internal value when external value changes
     * @param value the external value
     */
    writeValue(value: number): void;
    /**
     * Register onChange function
     * @param fn the function to register
     */
    registerOnChange(fn: any): void;
    /**
     * Register onTouched function
     * @param fn the function to register
     */
    registerOnTouched(fn: any): void;
    /**
     * Set the disabled state of the component
     * @param isDisabled disabled or not
     */
    setDisabledState?(isDisabled: boolean): void;
    /**
     * Update value on input
     * @param value the new value of the component
     */
    handleInput(value: number): void;
    /**
     * Prevent the paste event from completing
     * @param event the paste ClipboardEvent
     */
    preventPaste(event: ClipboardEvent): void;
    /**
     * Set the slider width
     * @private
     */
    private setSliderWidth;
    static ɵfac: i0.ɵɵFactoryDeclaration<SliderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SliderComponent, "wily-slider", never, { "value": "value"; "min": "min"; "max": "max"; "step": "step"; "disabled": "disabled"; "inputClassList": "inputClassList"; "unit": "unit"; "ariaLabel": "ariaLabel"; }, { "input": "input"; }, never, never>;
}
