import { ElementRef, OnDestroy, Renderer2 } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Directive to create a tooltip around the host element
 * TODO: Open/Close animation with AnimationFactory
 */
export declare class TooltipDirective implements OnDestroy {
    private element;
    private renderer;
    /**
     * The number of pixels from the host to offset the tooltip
     * @private
     */
    private readonly TOOLTIP_OFFSET;
    /**
     * Tooltip text input
     * @param text the text to set for the tooltip
     */
    set text(text: string);
    get text(): string;
    /**
     * The direction of the tooltip around the host element
     */
    tooltipPosition: 'left' | 'right' | 'top' | 'bottom';
    /**
     * Whether or not to disable the tooltip
     * @param disabled disabled or not
     */
    set tooltipDisabled(disabled: boolean);
    get disabled(): boolean;
    /**
     * The DIV element housing the tooltip
     * @private
     */
    private tooltip;
    /**
     * The tooltip text
     * @private
     */
    private _text;
    /**
     * Whether or not the tooltip is disabled
     * @private
     */
    private _disabled;
    /**
     * Array of scroll unlisten functions
     * @private
     */
    private scrollUnlisteners;
    /**
     * Get window scroll top
     * @private
     */
    private static getWindowScrollTop;
    /**
     * Get window scroll left
     * @private
     */
    private static getWindowScrollLeft;
    /**
     * Dependency injection site
     * @param element the host element
     * @param renderer the Angular renderer
     */
    constructor(element: ElementRef<HTMLElement>, renderer: Renderer2);
    /**
     * Destroy directive, invoke scroll unlisteners
     */
    ngOnDestroy(): void;
    /**
     * Handle host mouse enter event
     */
    onMouseEnter(): void;
    /**
     * Handle host mouse leave event
     */
    onMouseLeave(): void;
    /**
     * Handle host click event
     */
    onClick(): void;
    /**
     * Create tooltip, set the text and align it
     * @private
     */
    private showTooltip;
    /**
     * Add the tooltip to the DOM
     * @private
     */
    private createTooltip;
    /**
     * Set tooltip text
     * @private
     */
    private setTooltipText;
    /**
     * Align the tooltip to the input position or the next best fit
     * @private
     */
    private alignTooltip;
    /**
     * Align the tooltip to the left of the host
     * @private
     */
    private alignLeft;
    /**
     * Align the tooltip to the right of the host
     * @private
     */
    private alignRight;
    /**
     * Align the tooltip to the top of the host
     * @private
     */
    private alignTop;
    /**
     * Align the tooltip to the bottom of the host
     * @private
     */
    private alignBottom;
    /**
     * Get the host's top and left position offset by window scroll
     * @private
     */
    private getHostOffset;
    /**
     * Remove the tooltip from the DOM
     * @private
     */
    private deleteTooltip;
    /**
     * Checks if the tooltip fits in the window
     * @private
     */
    private tooltipOutOfWindow;
    /**
     * Listen for scrolling on all scrollable parents of the host element
     * @private
     */
    private addScrollListeners;
    /**
     * Invoke scroll unlisten functions and clear unlisteners list
     * @private
     */
    private removeScrollListeners;
    /**
     * Get the parent elements for the input element
     * @param element the element to get parents for
     * @param parents the parent elements
     * @private
     */
    private getParentElements;
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TooltipDirective, "[wilyTooltip]", never, { "text": "wilyTooltip"; "tooltipPosition": "tooltipPosition"; "tooltipDisabled": "tooltipDisabled"; }, {}, never>;
}
