import { Chart } from './chart.model';
/**
 * The representation of data to populate a column of the chart
 */
export declare class ColumnChartData {
    /**
     * Description of the column
     */
    description: string;
    /**
     * Column value
     */
    value: number;
    /**
     * Color of the column
     */
    color: string;
    /**
     * Column order position
     */
    position: number;
    /**
     * Array of data for a stacked bar chart
     */
    data: any[];
}
/**
 * Representation of a Column Chart for AM Charts
 */
export declare class ColumnChart extends Chart {
    /**
     * Defaults the type to serial so that it renders a column chart.
     */
    type: string;
    /**
     * Sets the margin right to 30 by default
     */
    marginRight: number;
    /**
     * The array of data to make the stacked bar chart
     */
    dataProvider: ColumnChartData[];
    /**
     * Duration of the render animation
     */
    startDuration: number;
    /**
     * Lets AMCharts know that the category for the column can be found in the
     * [ColumnChartData.description]{@link ColumnChartData#description}
     */
    categoryField: string;
    /**
     * Sets some general information for the chart
     */
    graphs: {
        balloonText: string;
        fillColorsField: string;
        fillAlphas: number;
        lineAlpha: number;
        type: string;
        valueField: string;
    }[];
    /**
     * Sets the axis data
     */
    categoryAxis: {
        gridPosition: string;
        labelRotation: number;
    };
    /**
     * Sets the cursor data
     */
    chartCursor: {
        categoryBalloonEnabled: boolean;
        cursorAlpha: number;
        zoomable: boolean;
    };
    /**
     * Sets the value axes data
     */
    valueAxes: {
        axisAlpha: number;
        position: string;
        title: string;
    }[];
    /**
     * Sets the listener to the clickGraphItem event
     */
    listeners: {
        event: string;
        method: any;
    }[];
    /**
     * Function to set the Y Axis Title
     *
     * @param title
     */
    setYAxisTitle(title: string): void;
    /**
     * Pass in a function so that it's called on click
     *
     * @param func
     */
    setClickListener(func: any): void;
}
