import { Chart } from './chart.model';
/**
 * Information for the Axis of a Gantt
 */
export declare class GanttValueAxis {
    /**
     * Defaults the type to date
     */
    type: string;
}
/**
 * Information about the Balloon Text for the Gantt Chart
 */
export declare class GanttGraph {
    /**
     * Sets the fill to be no opacity
     */
    fillAlphas: number;
    /**
     * Defaults the template for the balloon text
     */
    balloonText: string;
}
/**
 * The segment data for a piece of the Gantt chart
 */
export declare class GanttSegment {
    /**
     * The color
     */
    color: string;
    /**
     * The categorization
     */
    task: string;
    /**
     * The start date
     */
    start: string;
    /**
     * The label associated with the start date
     */
    startLabel: string;
    /**
     * The end date
     */
    end: string;
    /**
     * The label associated with the end date
     */
    endLabel: string;
}
/**
 * A Data Provider for the Gantt Chart
 */
export declare class GanttDataProvider {
    /**
     * The category of this data segment
     */
    category: string;
    /**
     * The data segments for this entry of the Gantt chart
     */
    segments: GanttSegment[];
}
/**
 * Gantt scroll bar configuration
 */
export declare class GanttValueScrollbar {
    /**
     * Auto-label the grid with a count
     */
    autoGridCount: boolean;
}
/**
 * Defaulted data for the Gantt Chart Cursor
 */
export declare class GanttChartCursor {
    /**
     * Color
     */
    cursorColor: string;
    /**
     * Are value balloons enabled?
     */
    valueBalloonsEnabled: boolean;
    /**
     * Cursor alpha
     */
    cursorAlpha: number;
    /**
     * Value line alpha
     */
    valueLineAlpha: number;
    /**
     * Balloons enabled?
     */
    valueLineBalloonEnabled: boolean;
    /**
     * Value lines enabled?
     */
    valueLineEnabled: boolean;
    /**
     * Chart zoomable?
     */
    zoomable: boolean;
    /**
     * Value zoomable?
     */
    valueZoomable: boolean;
}
/**
 * Representation of a Gantt Chart
 */
export declare class GanttChart extends Chart {
    /**
     * Chart type
     */
    type: string;
    /**
     * Right Margin
     */
    marginRight: number;
    /**
     * Time period for the Gantt
     */
    period: string;
    /**
     * Date Format
     */
    dataDateFormat: string;
    /**
     * Balloon Date Format
     */
    balloonDateFormat: string;
    /**
     * Column width
     */
    columnWidth: number;
    /**
     * Value axis
     */
    valueAxis: GanttValueAxis;
    /**
     * Brightness
     */
    brightnessStep: number;
    /**
     * Graph data
     */
    graph: GanttGraph;
    /**
     * Rotate
     */
    rotate: boolean;
    /**
     * Category Field
     */
    categoryField: string;
    /**
     * Segments Field
     */
    segmentsField: string;
    /**
     * Color Field
     */
    colorField: string;
    /**
     * Start Date for overall graph
     */
    startDate: string;
    /**
     * End Date for overall graph
     */
    endDate: string;
    /**
     * Start Date Field
     */
    startDateField: string;
    /**
     * End Date Field
     */
    endDateField: string;
    /**
     * Duration
     */
    durationField: string;
    /**
     * The data for the graph
     */
    dataProvider: GanttDataProvider[];
    /**
     * Defaulted scrollbar data
     */
    valueScrollbar: GanttValueScrollbar;
    /**
     * Defaulted cursor data
     */
    chartCursor: GanttChartCursor;
}
