import { Chart } from './chart.model';
/**
 * Model for a Pie Chart Legend
 */
export declare class PieChartLegend {
    /**
     * Position of the legend
     */
    position: string;
    /**
     * Margin Right in pixels
     */
    marginRight: number;
    /**
     * Auto-Margin
     */
    autoMargins: boolean;
    /**
     * Value Text template
     */
    valueText: string;
}
/**
 * Pie Chart Filter for visual representation
 */
export declare class PieChartFilter {
    /**
     * id
     */
    id: string;
    /**
     * Width
     */
    width: string;
    /**
     * Height
     */
    height: string;
    /**
     * Offset setup
     */
    feOffset: any;
    /**
     * Blur setup
     */
    feGaussianBlur: any;
    /**
     * Blend setup
     */
    feBlend: any;
}
/**
 * Sets up the Filter
 */
export declare class PieChartDefs {
    /**
     * List of filters
     */
    filter: PieChartFilter[];
}
/**
 * Representation of a slice of the PieChart
 */
export declare class PieChartData {
    /**
     * Description of data
     */
    description: string;
    /**
     * Data value
     */
    value: number;
}
/**
 * Representation of a PieChart in AMCharts
 */
export declare class PieChart extends Chart {
    /**
     * Default type to pie
     */
    type: string;
    /**
     * Labels Disabled
     */
    labelsEnabled: boolean;
    /**
     * Animation duration is 0, won't animate in
     */
    startDuration: number;
    /**
     * Add Class Names
     */
    addClassNames: boolean;
    /**
     * Enable the legend
     */
    legend: PieChartLegend;
    /**
     * Inner Radius is zero so it's a full pie not a donut chart
     */
    innerRadius: string;
    /**
     * Label Radius
     */
    labelRadius: number;
    /**
     * Init the Defs/Filter
     */
    defs: PieChartDefs;
    /**
     * Lets AMCharts know that the value for the pie slices can be found in the
     * [PieChartData.value]{@link PieChartData#value}
     */
    valueField: string;
    /**
     * Lets AMCharts know that the description for the pie slices can be found in the
     * [PieChartData.description]{@link PieChartData#description}
     */
    titleField: string;
    /**
     * Initializes the data to an empty array
     */
    dataProvider: PieChartData[];
    /**
     * Label template
     */
    labelText: string;
    /**
     * No auto margins
     */
    autoMargins: boolean;
    /**
     * Margin Top is 0
     */
    marginTop: number;
    /**
     * Margin Bottom is 0
     */
    marginBottom: number;
    /**
     * Margin Left is 0
     */
    marginLeft: number;
    /**
     * Margin Right is 0
     */
    marginRight: number;
    /**
     * Don't Pull Out
     */
    pullOutRadius: number;
    /**
     * An array of colors for the pie slices to use in order of appearance
     */
    colors: string[];
}
