import { Chart } from './chart.model';
/**
 * State Choropleth Data
 */
export declare class StateChoroplethData {
    /**
     * Map to Use
     */
    map: string;
    /**
     * Pull area from map
     */
    getAreasFromMap: boolean;
    /**
     * 95% Zoom
     */
    zoomLevel: number;
    /**
     * Bissect the map with this data
     */
    areas: StateChoroplethAreaStatistic[];
    /**
     * Images to use
     */
    images: any[];
}
/**
 * Individual Data points for map
 */
export declare class StateChoroplethAreaStatistic {
    /**
     * ID
     */
    id: string;
    /**
     * Value
     */
    value: number;
}
/**
 * Map Visual Settings
 */
export declare class StateChoroplethAreaSettings {
    /**
     * Disable Auto Zoom
     */
    autoZoom: boolean;
    /**
     * Allow Map interaction
     */
    selectable: boolean;
    /**
     * Solid Color
     */
    colorSolid: string;
    /**
     * Text Color
     */
    color: string;
    /**
     * Balloon Text Template
     */
    balloonText: string;
    /**
     * Color on rollover
     */
    rollOverColor: string;
    /**
     * Outline for rollover
     */
    rollOverOutlineColor: string;
    /**
     * Color for Selected
     */
    selectedColor: string;
}
/**
 * Choropleth Legend
 */
export declare class StateChoroplethValueLegend {
    /**
     * Left Margin
     */
    left: number;
    /**
     * Overall Min Value for Legend
     */
    minValue: string;
    /**
     * Overall Max Value for Legend
     */
    maxValue: string;
}
/**
 * StateChoropleth representation for AMMaps
 */
export declare class StateChoropleth extends Chart {
    /**
     * Map Type
     */
    type: string;
    /**
     * 10 color steps for shading
     */
    colorSteps: number;
    /**
     * Uses the pointer when things are clickable
     */
    useHandCursorOnClickableOjects: boolean;
    /**
     * The data for the map
     */
    dataProvider: StateChoroplethData;
    /**
     * Area Settings for the map for colors, outlines, labels, etc
     */
    areasSettings: StateChoroplethAreaSettings;
    /**
     * Image Settings
     */
    imagesSettings: {
        labelColor: string;
        mouseEnabled: boolean;
    };
    /**
     * Zoom settings
     */
    zoomControl: {
        minZoomLevel: number;
    };
    /**
     * Set this to enable the legend, off by default
     */
    valueLegend: StateChoroplethValueLegend;
}
