import { CognitoAuthSession } from 'amazon-cognito-auth-js';
import { Router } from '@angular/router';
/**
 * This is the service for interacting with Cognito. It should be extended and made Injectable.
 */
export declare abstract class CognitoAuthService {
    /**
     * Retry Count when there are errors logging inz
     */
    private retryCount;
    /**
     * Promise for App Initialization
     */
    private initPromise;
    /**
     * Cognito Auth Data
     */
    protected auth: any;
    /**
     * Cognito Auth Session
     */
    protected session: CognitoAuthSession;
    /**
     * Protected constructor
     */
    protected constructor();
    /**
     * Init function for App Initialization. Will create the Cognito session and the promise will resolve when it's all done.
     */
    init(): Promise<any>;
    /**
     * Promise deferment capability to support app initialization
     */
    private defer;
    /**
     * Cognito set up and actions on what to do what should be done when cognito is successful or fails.
     */
    private setupCognito;
    /**
     * Login function for Cognito
     */
    private login;
    /**
     * Returns whether the user is authenticated or not
     */
    authenticated(): boolean;
    /**
     * Logs out of the Cognito session
     */
    logout(): void;
    /**
     * Overrideable function to get a user from a child class, will re
     */
    getUser(): any;
    /**
     * Get the ID Token to embed in the header for REST calls to the back end
     */
    getIdToken(): string;
    /**
     * Token Refresh setup so that the session stays active.
     */
    private scheduleTokenRefresh;
    /**
     * Get the User from the Cognito Session
     */
    private getCognitoAuthUser;
    /**
     * To be provided by the class extension
     */
    abstract getRouter(): Router;
    /**
     * Returns the auth data to be used in this parent class
     */
    abstract getAuthData(): any;
}
